
# Slot: slot_usage


the redefinition of a slot in the context of the containing class definition.

URI: [meta:slot_usage](https://w3id.org/biolink/biolinkml/meta/slot_usage)

## Domain and Range

[ClassDefinition](ClassDefinition.md) ->  <sub>0..*</sub> [SlotDefinition](SlotDefinition.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
